@@ -55,22 +55,43 @@ class CDB(object):
                     is_pref_name=False, tui=None, pretty_name='',
                     desc=None, tokens_vocab=None, original_name=None,
                     is_unique=None):
-        """ Add a concept to internal CDB representation
+        r'''
+        Add a concept to internal Concept Database (CDB). Depending on what you are providing
+        this will add a large number of properties for each concept.
 
-        cui:  Identifier
-        name:  Concept name
-        onto:  Ontology from which the concept is taken
-        tokens:  A list of words existing in the name
-        snames:  if name is "heart attack" snames is
-                 ['heart', 'heart attack']
-        isupper:  If name in the original ontology is upper_cased
-        is_pref_name:  If this is the prefered name for this CUI
-        tui:  Semantic type
-        pretty_name:  Pretty name for this concept
-        desc:  Description of this concept - can take a lot of space
-        tokens_vocab:  Tokens that should be added to the vocabulary, usually not normalized
-        original_name: As in UMLS or any other vocab
-        """
+        Args:
+            cui (str):
+                Concept ID or unique identifer in this database, all concepts that have
+                the same CUI will be merged internally.
+
+            name (str):
+                Name for this concept, or the value that if found in free text can be linked to this concept.
+            onto (str):
+                Ontology from which the concept is taken (e.g. SNOMEDCT)
+            tokens (str, list of str):
+                Tokenized version of the name. Usually done vai spacy
+            snames (str, list of str):
+                Subnames of this name, have a look at medcat.prepare_cdb.PrepareCDB for details on how
+                to provide `snames`.Example: if name is "heart attack" snames is ['heart', 'heart attack']
+            isupper (boolean, optional):
+                If name in the original ontology is upper_cased
+            is_pref_name (boolean, optional):
+                If this is the prefered name for this CUI
+            tui (str, optional):
+                Semantic type identifier (have a look at TUIs in UMLS or SNOMED-CT)
+            pretty_name (str, optional):
+                Pretty name for this concept, really just the pretty name for the concept if it exists.
+            desc (str, optinal):
+                Description of this concept.
+            tokens_vocab (list of str, optional):
+                Tokens that should be added to the vocabulary, usually not normalized version of tokens.
+            original_name (str, optinal):
+                The orignal name from the source vocabulary, without any normalization.
+            is_unique (boolean, optional):
+                If set to False - you can require disambiguation for a name even if it is unique inside
+                of the current CDB. If set to True - you are forcing medcat to make a decision without
+                disambiguation even if it is required. Do not set this arg unless you are sure.
+        '''
         # Add the info property
         if cui not in self.cui2info:
             self.cui2info[cui] = {}
@@ -329,6 +350,7 @@ class CDB(object):
             log.info("COO_DICT cleaned, size was: {} and now is {}. In total \
                       {} items were removed".format(old_size, new_size, old_size-new_size))
 
+
     @property
     def coo_matrix(self):
         """ Get the COO Matrix as scikit dok_matrix
@@ -347,6 +369,7 @@ class CDB(object):
         """
         raise AttributeError("Can not set attribute coo_matrix")
 
+
     def reset_coo_matrix(self):
         """ Remove the COO-Matrix
         """
@@ -355,28 +378,6 @@ class CDB(object):
         self._coo_matrix = None
 
 
-    def merge_run_only(self, coo_dict, cui_count_ext):
-        """ Merges only the coo matrix and cui_count_ext
-        """
-        # Reset the coo matrix as it is not valid anymore
-        self.reset_coo_matrix()
-
-        # Merge coo_dict
-        for key in coo_dict.keys():
-            if key in self.coo_dict:
-                self.coo_dict[key] += coo_dict[key]
-            else:
-                self.coo_dict[key] = coo_dict[key]
-
-
-        # Merge cui_count_ext
-        for key in cui_count_ext.keys():
-            if key in self.cui_count_ext:
-                self.cui_count_ext[key] += cui_count_ext[key]
-            else:
-                self.cui_count_ext[key] = cui_count_ext[key]
-
-
     def save(self, path):
         with open(path, 'wb') as f:
             pickle.dump(self, f)
@@ -402,7 +403,74 @@ class CDB(object):
             self.__dict__ = pickle.load(f)
 
 
+    def import_training(self, cdb, overwrite=True):
+        r'''
+        This will import vector embeddings from another CDB. No new concept swill be added.
+        IMPORTANT it will not import name maps (cui2name or name2cui or ...).
+
+        Args:
+            cdb (medcat.cdb.CDB):
+                Concept database from which to import training vectors
+            overwrite (boolean):
+                If True all training data in the existing CDB will be overwritten, else
+                the average between the two training vectors will be taken.
+
+        Examples:
+            >>> new_cdb.import_traininig(cdb=old_cdb, owerwrite=True)
+        '''
+        # Import vectors and counts
+        for cui in self.cui2names:
+            if cui in cdb.cui_count:
+                if overwrite or cui not in self.cui_count:
+                    self.cui_count[cui] = cdb.cui_count[cui]
+                else:
+                    self.cui_count[cui] = (self.cui_count[cui] + cdb.cui_count[cui]) / 2
+
+            if cui in cdb.cui2context_vec:
+                if overwrite or cui not in self.cui2context_vec:
+                    self.cui2context_vec[cui] = cdb.cui2context_vec[cui]
+                else:
+                    self.cui2context_vec[cui] = (cdb.cui2context_vec[cui] + self.cui2context_vec[cui]) / 2
+
+
+            if cui in cdb.cui2context_vec_short:
+                if overwrite or cui not in self.cui2context_vec_short:
+                    self.cui2context_vec_short[cui] = cdb.cui2context_vec_short[cui]
+                else:
+                    self.cui2context_vec_short[cui] = (cdb.cui2context_vec_short[cui] + self.cui2context_vec_short[cui]) / 2
+
+            if cui in cdb.cui2context_vec_long:
+                if overwrite or cui not in self.cui2context_vec_long:
+                    self.cui2context_vec_long[cui] = cdb.cui2context_vec_long[cui]
+                else:
+                    self.cui2context_vec_long[cui] = (cdb.cui2context_vec_long[cui] + self.cui2context_vec_long[cui]) / 2 
+
+            if cui in cdb.cui_disamb_always:
+                self.cui_disamb_always[cui] = cdb.cui_disamb_always
+
+
+    def reset_cui_count(self, n=10):
+        r'''
+        Reset the CUI count for all concepts that received training, used when starting new unsupervised training
+        or for suppervised with annealing.
+
+        Args:
+            n (int, optional):
+                This will be set as the CUI count for all cuis in this CDB.
+
+        Examples:
+            >>> cdb.reset_cui_count()
+        '''
+        for cui in self.cui_count.keys():
+            self.cui_count[cui] = n
+
+
     def reset_training(self):
+        r'''
+        Will remove all training efforts - in other words all embeddings that are learnt
+        for concepts in the current CDB. Please note that this does not remove synonyms (names) that were
+        potentially added during supervised/online learning.
+        '''
         self.cui_count = {}
         self.cui2context_vec = {}
         self.cui2context_vec_short = {}
@@ -411,6 +479,7 @@ class CDB(object):
         self.cui_disamb_always = {}
         self.reset_coo_matrix()
 
+
     def filter_by_tui(self, tuis_to_keep):
         all_cuis = [c for c_list in [self.tui2cuis[tui] for tui in tuis_to_keep] for c in c_list]
         self.filter_by_cui(all_cuis)
